isError property
bool
get
isError
Returns true if the view is in error state
Implementation
bool get isError => this == ViewState.error;
Returns true if the view is in error state
bool get isError => this == ViewState.error;