User class

User model class

Inheritance

Constructors

User({required String id, required String name, required DateTime createdAt})
Creates a new User instance
const

Properties

createdAt DateTime
The createdAt of this User
final
hashCode int
The hash code for this object.
no setterinherited
id String
The id of this User
final
name String
The name of this User
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

copyWith({String? id, String? name, DateTime? createdAt}) User
Creates a copy of this User with the given fields replaced
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited