ViewState enum
Enum that represents different states a view can be in.
This helps manage the UI state of pages/views in a consistent way.
- Inheritance
- Available extensions
Values
- idle → const ViewState
-
The view is in its default, idle state
- busy → const ViewState
-
The view is performing an operation (loading/processing)
- error → const ViewState
-
The view encountered an error
- success → const ViewState
-
The view successfully completed an operation
- empty → const ViewState
-
The view has no data to display
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isBusy → bool
-
Available on ViewState, provided by the ViewStateExtension extension
Returns true if the view is in busy stateno setter - isEmpty → bool
-
Available on ViewState, provided by the ViewStateExtension extension
Returns true if the view is in empty stateno setter - isError → bool
-
Available on ViewState, provided by the ViewStateExtension extension
Returns true if the view is in error stateno setter - isIdle → bool
-
Available on ViewState, provided by the ViewStateExtension extension
Returns true if the view is in idle stateno setter - isSuccess → bool
-
Available on ViewState, provided by the ViewStateExtension extension
Returns true if the view is in success stateno setter - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited