onReady method
Called after the view is ready and displayed to the user Override this to perform final initialization (API calls, etc.)
Implementation
@override
Future<void> onReady() async {
super.onReady();
// Ready logic here - API calls, etc.
await _loadData();
}